nx.data.Query - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.data.Query Class

Extends nx.Iterable
Module: nx.data

- Index
- Methods
- Properties

## Item Index

### Methods

- all
- any
- average
- distinct
- each
- first
- groupBy
- join
- last
- max
- min
- reset
- select
- skip
- sum
- take
- toArray
- where

### Properties

- count

## Methods

### `all`

(

- `expr`

)
Boolean

#### Parameters:

- `expr` Object

#### Returns:

Boolean:

### `any`

(

- `expr`

)
Boolean

#### Parameters:

- `expr` Object

#### Returns:

Boolean:

### `average`

(

- `expr`

)
Number

#### Parameters:

- `expr` Object

#### Returns:

Number:

### `distinct`

(

- `expr`

)
chainable

#### Parameters:

- `expr` Object

### `each`

(

- `callback`
- `context`

)

Inherited from nx.Iterable:

#### Parameters:

- `callback` Object
- `context` Object

### `first`

(

- `expr`

)
Any

#### Parameters:

- `expr` Object

#### Returns:

Any:

### `groupBy`

(

- `expr`

)
chainable

#### Parameters:

- `expr` Object

### `join`

(

- `iter`
- `on`

)
chainable

#### Parameters:

- `iter` Object
- `on` Object

### `last`

(

- `expr`

)
Any

#### Parameters:

- `expr` Object

#### Returns:

Any:

### `max`

(

- `expr`

)
Number

#### Parameters:

- `expr` Object

#### Returns:

Number:

### `min`

(

- `expr`

)
Number

#### Parameters:

- `expr` Object

#### Returns:

Number:

### `reset`

()

Reset the query.

### `select`

(

- `expr`

)
Array

#### Parameters:

- `expr` Object

#### Returns:

Array:

### `skip`

(

- `count`

)
chainable

#### Parameters:

- `count` Object

### `sum`

(

- `expr`

)
Number

#### Parameters:

- `expr` Object

#### Returns:

Number:

### `take`

(

- `count`

)
chainable

#### Parameters:

- `count` Object

### `toArray`

() Array

Inherited from nx.Iterable

#### Returns:

Array:

### `where`

(

- `expr`

)
chainable

#### Parameters:

- `expr` Object

## Properties

### `count`

Number

Inherited from nx.Iterable: